@@ -1,5 +1,6 @@
 import os
 import os.path
+import sys
 import tarfile
 import tempfile
 from typing import IO, List
@@ -9,7 +10,7 @@ import click
 from treebeard.conf import treebeard_config
 
 
-def get_secrets_archive(files: List[IO] = []) -> IO[bytes]:
+def get_secrets_archive(files: List[IO] = [], confirm: bool = True) -> IO[bytes]:
     if treebeard_config:
         files += tuple((open(path, "r") for path in treebeard_config.secret))
 
@@ -26,7 +27,6 @@ def get_secrets_archive(files: List[IO] = []) -> IO[bytes]:
     with tempfile.NamedTemporaryFile(
         "wb", suffix=".tar.gz", delete=False
     ) as secrets_archive:
-        click.echo("\n")
         with tarfile.open(
             fileobj=secrets_archive, mode="w:gz", dereference=True
         ) as tar:
@@ -34,4 +34,9 @@ def get_secrets_archive(files: List[IO] = []) -> IO[bytes]:
                 click.echo(f"  Including {f.name}")
                 tar.add(f.name)
 
+    if not (
+        confirm or click.confirm("Confirm secret file set is correct?", default=True)
+    ):
+        click.echo("Exiting")
+        sys.exit()
     return secrets_archive
