@@ -6,7 +6,7 @@ from treebeard.version import get_version
 
 
 def setup_sentry():
-    sentry_sdk.init(
+    sentry_sdk.init(  # type: ignore
         "https://58543632a309471a88bb99f4f6bbdca0@sentry.io/2846147", environment=env
     )
 
